$ yacli_

# Install

## Pip

`sudo apt-get install python-pip python-dev build-essential`
`sudo pip install --upgrade pip`

## Dependency

`sudo pip install requirement.txt`

## Yacli

`sudo pip install --editable .`

## Actito home

ACTITO__HOME variable is used to define the directory where all actito projects
are.

Add `export ACTITO_HOME=~/path/to/actito/directory` in your .bashrc, .zshrc or
.profile.

# Usage

## List of commands

`yacli`

## Detail for a command

`yacli CMD --help`



